sudo rm -rf ./trinity_out_dir
sudo rm -rf ./trinity_ext_sample_data_docker
sudo rm -rf ./trinity_ext_sample_data_singularity
sudo rm -rf ./trinity_ext_sample_data
sudo rm -rf ./trinity_out_dir_docker
